@@ -6,6 +6,8 @@ use warnings;
 use LWP::UserAgent;
 #~ use Carp qw(croak carp);
 
+=encoding utf8
+
 =head1 ПРИВЕТСТВИЕ
 
 Други, братаны, потьсёны и многоуважаемый женский пол!
@@ -20,53 +22,65 @@ use LWP::UserAgent;
 lib::remote - Удаленное использование модулей. Загружает исходник модуля с удаленного сервера. Одна манипуляция с @INC - push @INC, sub {}, которая возвращает filehandle для контента, полученного удаленно.
 
 Подсмотрено из http://forum.codecall.net/topic/64285-perl-use-modules-on-remote-servers/
+
 Кто-то еще стырил http://www.linuxdigest.org/2012/06/use-modules-on-remote-servers/ (поздняя дата и есть ошибки)
 
 =head1 VERSION
 
-Version 0.01
+Version 0.02
 
 =cut
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 
 =head1 FAQ
 
 Q: Зачем?
+
 A: За лосем.
 
 Q: Почему?
+
 A: По кочану.
 
+
 =head1 SYNOPSIS
 
-Все просто, потьсёны:
+Все просто, потьсёны, по аналогии с:
 
-по аналогии с 
     use lib '../to/any/local/lib';
 
-делаем
+делаем:
+
     use lib::remote 'http://<хост>/site-perl/.../';
     use My::Module1;
     ...
-Искомый модуль будет запрашиваться как в локальном варианте, дописывая в конце URL: http://<хост>/.../My/Module1.pm
+
+Искомый модуль будет запрашиваться как в локальном варианте, дописывая в конце URL: http://<хост>/site-perl/.../My/Module1.pm
 
 Допустим, УРЛ сложнее, не содержит имени модуля или используются параметры: https://<хост>/.../?key=ede35ac1208bbf479&...
+
 Тогда делаем пары ключ->значение:
+
     use lib::remote
         'http://....',
         'Some::Module1'=>'https://<хост>/.../?key=ede35ac1208bbf479&...',
         'SomeModule2'=>'ssh://user:pass@host:/..../SomeModule2.pm',
     ;
-    #use Some::Module1; не нужно, уже сделано
-    use SomeModule2 qw(func1 func2);# только если нужно что-то импортировать, простое use уже сделано
+    #use Some::Module1; не нужно, уже сделано (см. L</"Конфигурация модуля">)
+    use SomeModule2 qw(func1 func2);# только, если нужно что-то импортировать, простое use уже сделано (см. L</"Конфигурация модуля">)
     use parent 'Some::Module1';
     ...
 
 Не трудно догадаться, что вычленение пар в общем списке происходит по специфике URI.
-Внимание. Конкретно указанный модуль через пару будет искаться сначала в своем урл, а потом в безымянных безключевых параметрах.
+
+=head3 Внимание
+
+Конкретно указанный модуль через пару будет искаться сначала в своем урл, а потом в безымянных безключевых параметрах.
+
 При многократном вызове use lib::remote все параметры и урлы сохраняются, аналогично use lib '';, но естественно не в @INC.
+
 Повторюсь, в @INC помещается только один диспетчер.
 
 =head2 Расширенный синтаксис
@@ -77,9 +91,31 @@ A: По кочану.
         'SomeModule2'=>['ssh://user@host:/..../SomeModule2.pm', 'pass'=>..., ...],
     ;
     ...
+
 Видно, что URL передается первым элементом массива, остальные элементы как пары дополнительных опций.
 
+=head2 Конфигурация модуля
+
+    use lib::remote
+        'lib::remote'=>[opt1 =>..., opt2 =>..., ....],
+        ...
+    ;
+    ...
+
+Видно, что ключ должен совпадать с именем этого модуля 'lib::remote'. Основные опции:
+
+=over 4
+
+=item * autouse => 0. По умолчанию 1, т.е. для конкретных модулей 'Some::Module1'=> .... срабатывает use Some::Module1;
+
+=item * что еще?
+
+=back
+
+
+
 Если 'http://...', 'https://...', 'ftp://...', 'file://...' то нужен LWP::UserAgent
+
 Если 'ssh://...' - TODO
 
 Url может возвращать сразу пачку модулей (package). В этом случае писать ключом один модуль и дополнительно вызывать use для остальных модулей.
@@ -94,6 +130,9 @@ Url может возвращать сразу пачку модулей (packag
 
 =cut
 
+my %config = (
+    autouse =>1,
+);
 my $ua = LWP::UserAgent->new;
 #~ $ua->timeout(10);
 my %modules = ();#сохранение списка пар "Имя::модуля"=>[url]
@@ -111,20 +150,20 @@ BEGIN {
         my $content;
         if (my $m = $modules{$mod}) {# конкретный модуль
             my $url = ref($m) ? $m->[0] : $m;
-            if ($url =~ m#^(http|https|ftp|file)://#) {#LWP
+            if ( $url =~ m#^(http|https|ftp|file)://# ) {#LWP
                 $content = lwpget($url);
-                eval $content;
-                if ($@) {
-                    $url =~ s#/$##;
-                    $content = lwpget("$url/$arg");
-                }
+                #~ eval $content;
+                #~ if ($@) {
+                    #~ $url =~ s#/$##;
+                    #~ $content = lwpget("$url/$arg");
+                #~ }
             }
         }
         unless ($content) {# перебор удаленных папок
             for (@base_ulrs) {
                 s#/$##;
                 my $url = "$_/$arg";
-                if ($url =~ m#^(http|https|ftp|file)://#) {#LWP
+                if ( $url =~ m#^(http|https|ftp|file)://# ) {#LWP
                     $content = lwpget($url);
                     last if $content;
                 }
@@ -145,9 +184,14 @@ sub import {
     my %new_mods = ();# для этого захода
     my %unique = @base_ulrs;
     map {# разбор аргументов
-        if (ref($_) || m#^\w+://#) {
+        if ( ref($_) || m#^\w+://# ) {
             if ($module) {
-                $new_mods{$module} = $_;
+                if ( $module eq __PACKAGE__ ) {
+                    my %opt = @$_;
+                    map {$config{$_} = $opt{$_};} keys %opt;
+                } else {
+                    $new_mods{$module} = $_;
+                }
                 $module = undef;
             } else {
                 #~ print "push base_url\n";
@@ -167,9 +211,11 @@ sub import {
         #~ my %opt = @opt;
         #~ my $file =$url;
         #~ $file =~ s#::#/#g;
-        eval "use $_;";# вот сразу заход в диспетчер
-        if ($@) {
-            warn "Возможно проблемы с модулем [$_]: $@";
+        if ( $config{autouse} ) {
+            eval "use $_;";# вот сразу заход в диспетчер
+            if ($@) {
+                warn "Возможно проблемы с модулем [$_]: $@";
+            }
         }
     } keys %new_mods;
     #~ print "import: ", (map {"[$_]";} @base_ulrs), "\n";
@@ -179,7 +225,7 @@ sub lwpget {
     my $url = shift;
     #~ print "get: $self";
     my $get = $ua->get($url);
-    if($get->is_success) {
+    if ( $get->is_success ) {
         #~ print "lwpget success [$url]\n";
         return $get->decoded_content;# ??? ->content нужно отладить
     } else {
@@ -190,7 +236,7 @@ sub lwpget {
 
 =head1 AUTHOR
 
-Mikhail Che, C<< <m.che[собачка]aukama.dyndns.org> >>
+Mikhail Che, C<< <m.che[пёсик]aukama.dyndns.org> >>
 
 =head1 BUGS
 
@@ -237,8 +283,9 @@ L<http://search.cpan.org/dist/lib-remote/>
 
 =head1 SEE ALSO
 
-See L<PAR>
-See L<Remote::Use>
+Глянь L<PAR>
+
+Глянь L<Remote::Use>
 
 =head1 LICENSE AND COPYRIGHT
 
